import codecs
from setuptools import setup

setup(
    name='geoip2fast',
    version='1.1.8',
    description='GeoIP2Fast is the fastest GeoIP2 country/city/asn lookup library that supports IPv4 and IPv6. A search takes less than 0.00003 seconds. It has its own data file updated with Maxmind-Geolite2-CSV and is Pure Python!',
    url='https://github.com/rabuchaim/geoip2fast',
    author='Ricardo Abuchaim',
    author_email='ricardoabuchaim@gmail.com',
    maintainer='Ricardo Abuchaim',
    maintainer_email='ricardoabuchaim@gmail.com',
    project_urls={
        "Issue Tracker": "https://github.com/rabuchaim/geoip2fast/issues",
        "Latest DAT files": "https://github.com/rabuchaim/geoip2fast/releases/latest",
    },    
    bugtrack_url='https://github.com/rabuchaim/geoip2fast/issues',    
    license='MIT',
    packages=['geoip2fast'],
    keywords=['geoip','geoip2','geolite2','maxmind','geoip2fast','geolocation','geolocalization','geo ip','ip','geo','ipv4','ipv6','pure-python','purepython','pure python','geoiptofast','geoiptoofast','geoip2dat'],
    package_dir = {'geoip2fast': 'geoip2fast'},
    package_data={
        'geoip2fast': ['CHANGELOG','geoip2fast.dat.gz','geoip2fast-ipv6.dat.gz','geoip2fast-asn.dat.gz','geoip2fast-asn-ipv6.dat.gz','geoip2fast-city.dat.gz','geoip2fast-city-ipv6.dat.gz','tests/geoip2fast_test.py','tests/speed_test.py','tests/coverage_test.py','tests/compare_with_mmdb.py','tests/random_test.py','tests/geoipcli.py'],
    },
    python_requires=">=3.7",    
    install_requires=[],
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Topic :: Security',
        'Topic :: Internet',
        'Topic :: Internet :: Finger',
        'Topic :: Scientific/Engineering',
        'Topic :: Scientific/Engineering :: Information Analysis',
        'Topic :: System :: Networking',
        'Topic :: System :: Monitoring',
        'Topic :: System :: Networking',
        'Topic :: System :: Networking :: Monitoring',
        'Topic :: System :: Systems Administration',
        'Topic :: Software Development :: Libraries',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Software Development :: Localization',
        'Topic :: Utilities',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'Intended Audience :: Information Technology',
        'Intended Audience :: System Administrators',
        'License :: OSI Approved :: MIT License',
        'Operating System :: MacOS',
        'Operating System :: Microsoft :: Windows :: Windows 10',
        'Operating System :: Microsoft :: Windows :: Windows 11',
        'Operating System :: Unix',
        'Operating System :: POSIX',
        'Operating System :: POSIX :: Linux',
        'Operating System :: POSIX :: BSD',
        'Operating System :: POSIX :: BSD :: FreeBSD',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',  
        'Programming Language :: Python :: 3.11',
        'Programming Language :: Python :: 3.12',
        'Programming Language :: Python :: 3.13',
        'Programming Language :: Python :: Implementation :: PyPy',
        
    ],
    include_package_data=True,
    long_description=codecs.open("README.md","r","utf-8").read(),
    long_description_content_type='text/markdown',
    entry_points={
        'console_scripts': [
            'geoip2fast = geoip2fast.geoip2fast:main_function',
            'geoip2dat = geoip2fast.geoip2dat:main_function'
        ]
    },
)
